# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["LiveViewCreateParams", "Guardrails"]


class LiveViewCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    expires_in_ms: Annotated[float, PropertyInfo(alias="expiresInMs")]
    """How long the live view URLs remain valid, in milliseconds.

    Default: 5 minutes. Max: 60 minutes.
    """

    guardrails: Guardrails
    """Connection guardrails. Use `{ mode: 'readonly' }` to generate a view-only link."""

    mode: Literal["devtools", "tab", "full"]
    """
    UI mode: 'devtools' (Chrome DevTools), 'tab' (single tab view), 'full'
    (multi-tab browser)
    """

    target_id: Annotated[str, PropertyInfo(alias="targetId")]
    """Target ID (page) to connect to.

    If omitted, auto-resolves to the first active page.
    """


class Guardrails(TypedDict, total=False):
    """Connection guardrails. Use `{ mode: 'readonly' }` to generate a view-only link."""

    mode: Required[Literal["readonly"]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ...types.zones import transformations_allowed_origin_edit_params
from ..._base_client import make_request_options
from ...types.zones.transformations_allowed_origins import TransformationsAllowedOrigins

__all__ = ["TransformationsAllowedOriginsResource", "AsyncTransformationsAllowedOriginsResource"]


class TransformationsAllowedOriginsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TransformationsAllowedOriginsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return TransformationsAllowedOriginsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TransformationsAllowedOriginsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return TransformationsAllowedOriginsResourceWithStreamingResponse(self)

    def edit(
        self,
        *,
        zone_id: str,
        value: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[TransformationsAllowedOrigins]:
        """
        Media Transformations Allowed Origins restricts transformations for images and
        video served through Cloudflare's network to requests originating from specified
        domains. Refer to the Image Transformations and Video Transformations
        documentation for more information.

        Args:
          zone_id: Identifier.

          value: Comma-separated list of allowed origin domains for image and video
              transformations. Use "\\**" to allow all origins (default).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._patch(
            path_template("/zones/{zone_id}/settings/transformations_allowed_origins", zone_id=zone_id),
            body=maybe_transform(
                {"value": value}, transformations_allowed_origin_edit_params.TransformationsAllowedOriginEditParams
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[TransformationsAllowedOrigins]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[TransformationsAllowedOrigins]], ResultWrapper[TransformationsAllowedOrigins]),
        )

    def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[TransformationsAllowedOrigins]:
        """
        Media Transformations Allowed Origins restricts transformations for images and
        video served through Cloudflare's network to requests originating from specified
        domains. Refer to the Image Transformations and Video Transformations
        documentation for more information.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get(
            path_template("/zones/{zone_id}/settings/transformations_allowed_origins", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[TransformationsAllowedOrigins]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[TransformationsAllowedOrigins]], ResultWrapper[TransformationsAllowedOrigins]),
        )


class AsyncTransformationsAllowedOriginsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTransformationsAllowedOriginsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTransformationsAllowedOriginsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTransformationsAllowedOriginsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncTransformationsAllowedOriginsResourceWithStreamingResponse(self)

    async def edit(
        self,
        *,
        zone_id: str,
        value: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[TransformationsAllowedOrigins]:
        """
        Media Transformations Allowed Origins restricts transformations for images and
        video served through Cloudflare's network to requests originating from specified
        domains. Refer to the Image Transformations and Video Transformations
        documentation for more information.

        Args:
          zone_id: Identifier.

          value: Comma-separated list of allowed origin domains for image and video
              transformations. Use "\\**" to allow all origins (default).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._patch(
            path_template("/zones/{zone_id}/settings/transformations_allowed_origins", zone_id=zone_id),
            body=await async_maybe_transform(
                {"value": value}, transformations_allowed_origin_edit_params.TransformationsAllowedOriginEditParams
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[TransformationsAllowedOrigins]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[TransformationsAllowedOrigins]], ResultWrapper[TransformationsAllowedOrigins]),
        )

    async def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[TransformationsAllowedOrigins]:
        """
        Media Transformations Allowed Origins restricts transformations for images and
        video served through Cloudflare's network to requests originating from specified
        domains. Refer to the Image Transformations and Video Transformations
        documentation for more information.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._get(
            path_template("/zones/{zone_id}/settings/transformations_allowed_origins", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[TransformationsAllowedOrigins]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[TransformationsAllowedOrigins]], ResultWrapper[TransformationsAllowedOrigins]),
        )


class TransformationsAllowedOriginsResourceWithRawResponse:
    def __init__(self, transformations_allowed_origins: TransformationsAllowedOriginsResource) -> None:
        self._transformations_allowed_origins = transformations_allowed_origins

        self.edit = to_raw_response_wrapper(
            transformations_allowed_origins.edit,
        )
        self.get = to_raw_response_wrapper(
            transformations_allowed_origins.get,
        )


class AsyncTransformationsAllowedOriginsResourceWithRawResponse:
    def __init__(self, transformations_allowed_origins: AsyncTransformationsAllowedOriginsResource) -> None:
        self._transformations_allowed_origins = transformations_allowed_origins

        self.edit = async_to_raw_response_wrapper(
            transformations_allowed_origins.edit,
        )
        self.get = async_to_raw_response_wrapper(
            transformations_allowed_origins.get,
        )


class TransformationsAllowedOriginsResourceWithStreamingResponse:
    def __init__(self, transformations_allowed_origins: TransformationsAllowedOriginsResource) -> None:
        self._transformations_allowed_origins = transformations_allowed_origins

        self.edit = to_streamed_response_wrapper(
            transformations_allowed_origins.edit,
        )
        self.get = to_streamed_response_wrapper(
            transformations_allowed_origins.get,
        )


class AsyncTransformationsAllowedOriginsResourceWithStreamingResponse:
    def __init__(self, transformations_allowed_origins: AsyncTransformationsAllowedOriginsResource) -> None:
        self._transformations_allowed_origins = transformations_allowed_origins

        self.edit = async_to_streamed_response_wrapper(
            transformations_allowed_origins.edit,
        )
        self.get = async_to_streamed_response_wrapper(
            transformations_allowed_origins.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["NELEditParams", "Value"]


class NELEditParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier of the zone."""

    value: Required[Value]
    """The NEL configuration value."""


class Value(TypedDict, total=False):
    """The NEL configuration value."""

    enabled: Required[bool]
    """Whether Network Error Logging is enabled for the zone.

    When enabled, browsers report network errors to Cloudflare's NEL endpoint.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Type, Iterable, Optional, cast
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ....pagination import SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ...._base_client import AsyncPaginator, make_request_options
from ....types.email_security.settings import (
    content_policy_edit_params,
    content_policy_list_params,
    content_policy_batch_params,
    content_policy_create_params,
)
from ....types.email_security.settings.content_policy_get_response import ContentPolicyGetResponse
from ....types.email_security.settings.content_policy_edit_response import ContentPolicyEditResponse
from ....types.email_security.settings.content_policy_list_response import ContentPolicyListResponse
from ....types.email_security.settings.content_policy_batch_response import ContentPolicyBatchResponse
from ....types.email_security.settings.content_policy_create_response import ContentPolicyCreateResponse
from ....types.email_security.settings.content_policy_delete_response import ContentPolicyDeleteResponse

__all__ = ["ContentPoliciesResource", "AsyncContentPoliciesResource"]


class ContentPoliciesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ContentPoliciesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ContentPoliciesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ContentPoliciesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ContentPoliciesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        enabled: bool,
        name: str,
        pattern: str,
        targets: List[Literal["SUBJECT", "BODY"]],
        notes: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyCreateResponse]:
        """Creates a new content policy.

        Emails whose subject or body matches the pattern
        will be subject to the configured action.

        Args:
          account_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/email-security/settings/content_policies", account_id=account_id),
            body=maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "pattern": pattern,
                    "targets": targets,
                    "notes": notes,
                },
                content_policy_create_params.ContentPolicyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyCreateResponse]], ResultWrapper[ContentPolicyCreateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        direction: Literal["asc", "desc"] | Omit = omit,
        enabled: bool | Omit = omit,
        name: str | Omit = omit,
        order: Literal["name", "created_at"] | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        search: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[ContentPolicyListResponse]:
        """Returns a paginated list of content policies.

        These policies match against the
        subject or body of emails using a pattern. Supports filtering by name or enabled
        status, and searching across name and pattern fields.

        Args:
          account_id: Identifier.

          direction: The sorting direction.

          enabled: Filter by enabled status.

          name: Filter by exact policy name.

          order: Field to sort by.

          page: Current page within paginated list of results.

          per_page: The number of results per page. Maximum value is 1000.

          search: Search term for filtering records. Behavior may change.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/email-security/settings/content_policies", account_id=account_id),
            page=SyncV4PagePaginationArray[ContentPolicyListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "direction": direction,
                        "enabled": enabled,
                        "name": name,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                        "search": search,
                    },
                    content_policy_list_params.ContentPolicyListParams,
                ),
            ),
            model=ContentPolicyListResponse,
        )

    def delete(
        self,
        policy_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyDeleteResponse]:
        """Removes a content policy.

        After deletion, emails will no longer be evaluated
        against this pattern.

        Args:
          account_id: Identifier.

          policy_id: Content policy identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not policy_id:
            raise ValueError(f"Expected a non-empty value for `policy_id` but received {policy_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/{policy_id}",
                account_id=account_id,
                policy_id=policy_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyDeleteResponse]], ResultWrapper[ContentPolicyDeleteResponse]),
        )

    def batch(
        self,
        *,
        account_id: str,
        deletes: Iterable[content_policy_batch_params.Delete],
        patches: Iterable[content_policy_batch_params.Patch],
        posts: Iterable[content_policy_batch_params.Post],
        puts: Iterable[content_policy_batch_params.Put],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyBatchResponse]:
        """Executes multiple operations atomically.

        All four operation arrays (deletes,
        patches, puts, posts) are required and executed in order. Send empty arrays for
        unused operations.

        Args:
          account_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/batch", account_id=account_id
            ),
            body=maybe_transform(
                {
                    "deletes": deletes,
                    "patches": patches,
                    "posts": posts,
                    "puts": puts,
                },
                content_policy_batch_params.ContentPolicyBatchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyBatchResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyBatchResponse]], ResultWrapper[ContentPolicyBatchResponse]),
        )

    def edit(
        self,
        policy_id: str,
        *,
        account_id: str,
        enabled: bool | Omit = omit,
        name: str | Omit = omit,
        notes: Optional[str] | Omit = omit,
        pattern: str | Omit = omit,
        targets: List[Literal["SUBJECT", "BODY"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyEditResponse]:
        """Updates an existing content policy.

        Only provided fields will be modified.

        Args:
          account_id: Identifier.

          policy_id: Content policy identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not policy_id:
            raise ValueError(f"Expected a non-empty value for `policy_id` but received {policy_id!r}")
        return self._patch(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/{policy_id}",
                account_id=account_id,
                policy_id=policy_id,
            ),
            body=maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "notes": notes,
                    "pattern": pattern,
                    "targets": targets,
                },
                content_policy_edit_params.ContentPolicyEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyEditResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyEditResponse]], ResultWrapper[ContentPolicyEditResponse]),
        )

    def get(
        self,
        policy_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyGetResponse]:
        """
        Retrieves details for a specific content policy including its pattern, targets,
        and metadata.

        Args:
          account_id: Identifier.

          policy_id: Content policy identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not policy_id:
            raise ValueError(f"Expected a non-empty value for `policy_id` but received {policy_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/{policy_id}",
                account_id=account_id,
                policy_id=policy_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyGetResponse]], ResultWrapper[ContentPolicyGetResponse]),
        )


class AsyncContentPoliciesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncContentPoliciesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncContentPoliciesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncContentPoliciesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncContentPoliciesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        enabled: bool,
        name: str,
        pattern: str,
        targets: List[Literal["SUBJECT", "BODY"]],
        notes: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyCreateResponse]:
        """Creates a new content policy.

        Emails whose subject or body matches the pattern
        will be subject to the configured action.

        Args:
          account_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/email-security/settings/content_policies", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "pattern": pattern,
                    "targets": targets,
                    "notes": notes,
                },
                content_policy_create_params.ContentPolicyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyCreateResponse]], ResultWrapper[ContentPolicyCreateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        direction: Literal["asc", "desc"] | Omit = omit,
        enabled: bool | Omit = omit,
        name: str | Omit = omit,
        order: Literal["name", "created_at"] | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        search: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[ContentPolicyListResponse, AsyncV4PagePaginationArray[ContentPolicyListResponse]]:
        """Returns a paginated list of content policies.

        These policies match against the
        subject or body of emails using a pattern. Supports filtering by name or enabled
        status, and searching across name and pattern fields.

        Args:
          account_id: Identifier.

          direction: The sorting direction.

          enabled: Filter by enabled status.

          name: Filter by exact policy name.

          order: Field to sort by.

          page: Current page within paginated list of results.

          per_page: The number of results per page. Maximum value is 1000.

          search: Search term for filtering records. Behavior may change.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/email-security/settings/content_policies", account_id=account_id),
            page=AsyncV4PagePaginationArray[ContentPolicyListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "direction": direction,
                        "enabled": enabled,
                        "name": name,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                        "search": search,
                    },
                    content_policy_list_params.ContentPolicyListParams,
                ),
            ),
            model=ContentPolicyListResponse,
        )

    async def delete(
        self,
        policy_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyDeleteResponse]:
        """Removes a content policy.

        After deletion, emails will no longer be evaluated
        against this pattern.

        Args:
          account_id: Identifier.

          policy_id: Content policy identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not policy_id:
            raise ValueError(f"Expected a non-empty value for `policy_id` but received {policy_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/{policy_id}",
                account_id=account_id,
                policy_id=policy_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyDeleteResponse]], ResultWrapper[ContentPolicyDeleteResponse]),
        )

    async def batch(
        self,
        *,
        account_id: str,
        deletes: Iterable[content_policy_batch_params.Delete],
        patches: Iterable[content_policy_batch_params.Patch],
        posts: Iterable[content_policy_batch_params.Post],
        puts: Iterable[content_policy_batch_params.Put],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyBatchResponse]:
        """Executes multiple operations atomically.

        All four operation arrays (deletes,
        patches, puts, posts) are required and executed in order. Send empty arrays for
        unused operations.

        Args:
          account_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/batch", account_id=account_id
            ),
            body=await async_maybe_transform(
                {
                    "deletes": deletes,
                    "patches": patches,
                    "posts": posts,
                    "puts": puts,
                },
                content_policy_batch_params.ContentPolicyBatchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyBatchResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyBatchResponse]], ResultWrapper[ContentPolicyBatchResponse]),
        )

    async def edit(
        self,
        policy_id: str,
        *,
        account_id: str,
        enabled: bool | Omit = omit,
        name: str | Omit = omit,
        notes: Optional[str] | Omit = omit,
        pattern: str | Omit = omit,
        targets: List[Literal["SUBJECT", "BODY"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyEditResponse]:
        """Updates an existing content policy.

        Only provided fields will be modified.

        Args:
          account_id: Identifier.

          policy_id: Content policy identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not policy_id:
            raise ValueError(f"Expected a non-empty value for `policy_id` but received {policy_id!r}")
        return await self._patch(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/{policy_id}",
                account_id=account_id,
                policy_id=policy_id,
            ),
            body=await async_maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "notes": notes,
                    "pattern": pattern,
                    "targets": targets,
                },
                content_policy_edit_params.ContentPolicyEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyEditResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyEditResponse]], ResultWrapper[ContentPolicyEditResponse]),
        )

    async def get(
        self,
        policy_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentPolicyGetResponse]:
        """
        Retrieves details for a specific content policy including its pattern, targets,
        and metadata.

        Args:
          account_id: Identifier.

          policy_id: Content policy identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not policy_id:
            raise ValueError(f"Expected a non-empty value for `policy_id` but received {policy_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/email-security/settings/content_policies/{policy_id}",
                account_id=account_id,
                policy_id=policy_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ContentPolicyGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentPolicyGetResponse]], ResultWrapper[ContentPolicyGetResponse]),
        )


class ContentPoliciesResourceWithRawResponse:
    def __init__(self, content_policies: ContentPoliciesResource) -> None:
        self._content_policies = content_policies

        self.create = to_raw_response_wrapper(
            content_policies.create,
        )
        self.list = to_raw_response_wrapper(
            content_policies.list,
        )
        self.delete = to_raw_response_wrapper(
            content_policies.delete,
        )
        self.batch = to_raw_response_wrapper(
            content_policies.batch,
        )
        self.edit = to_raw_response_wrapper(
            content_policies.edit,
        )
        self.get = to_raw_response_wrapper(
            content_policies.get,
        )


class AsyncContentPoliciesResourceWithRawResponse:
    def __init__(self, content_policies: AsyncContentPoliciesResource) -> None:
        self._content_policies = content_policies

        self.create = async_to_raw_response_wrapper(
            content_policies.create,
        )
        self.list = async_to_raw_response_wrapper(
            content_policies.list,
        )
        self.delete = async_to_raw_response_wrapper(
            content_policies.delete,
        )
        self.batch = async_to_raw_response_wrapper(
            content_policies.batch,
        )
        self.edit = async_to_raw_response_wrapper(
            content_policies.edit,
        )
        self.get = async_to_raw_response_wrapper(
            content_policies.get,
        )


class ContentPoliciesResourceWithStreamingResponse:
    def __init__(self, content_policies: ContentPoliciesResource) -> None:
        self._content_policies = content_policies

        self.create = to_streamed_response_wrapper(
            content_policies.create,
        )
        self.list = to_streamed_response_wrapper(
            content_policies.list,
        )
        self.delete = to_streamed_response_wrapper(
            content_policies.delete,
        )
        self.batch = to_streamed_response_wrapper(
            content_policies.batch,
        )
        self.edit = to_streamed_response_wrapper(
            content_policies.edit,
        )
        self.get = to_streamed_response_wrapper(
            content_policies.get,
        )


class AsyncContentPoliciesResourceWithStreamingResponse:
    def __init__(self, content_policies: AsyncContentPoliciesResource) -> None:
        self._content_policies = content_policies

        self.create = async_to_streamed_response_wrapper(
            content_policies.create,
        )
        self.list = async_to_streamed_response_wrapper(
            content_policies.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            content_policies.delete,
        )
        self.batch = async_to_streamed_response_wrapper(
            content_policies.batch,
        )
        self.edit = async_to_streamed_response_wrapper(
            content_policies.edit,
        )
        self.get = async_to_streamed_response_wrapper(
            content_policies.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["BlockSenderBatchResponse", "Delete", "Patch", "Post", "Put"]


class Delete(BaseModel):
    id: str
    """Blocked sender pattern identifier."""


class Patch(BaseModel):
    """A blocked sender pattern."""

    id: Optional[str] = None
    """Blocked sender pattern identifier."""

    comments: Optional[str] = None

    created_at: Optional[datetime] = None

    is_regex: Optional[bool] = None

    last_modified: Optional[datetime] = None
    """Deprecated, use `modified_at` instead. End of life: November 1, 2026."""

    modified_at: Optional[datetime] = None

    pattern: Optional[str] = None
    """The pattern value to match.

    The format depends on `pattern_type`: a valid email address for EMAIL (e.g.
    `user@example.com`), a valid domain name for DOMAIN (e.g. `example.com`), or a
    plain IPv4 or IPv6 address or CIDR block for IP (e.g. `1.2.3.4`, `1.2.3.0/24`,
    `2606:4700:4700::1111`, or `2606:4700:4700::/48`); the API rejects private or
    unique-local, loopback, link-local, unspecified, and IPv4 broadcast addresses,
    including their IPv4-mapped IPv6 equivalents.
    """

    pattern_type: Optional[Literal["EMAIL", "DOMAIN", "IP", "UNKNOWN"]] = None
    """Type of pattern matching.

    - EMAIL: matches a full email address (e.g. `user@example.com`)
    - DOMAIN: matches a domain name (e.g. `example.com`)
    - IP: matches a plain IPv4 or IPv6 address (e.g. `1.2.3.4` or
      `2606:4700:4700::1111`) or CIDR block (e.g. `1.2.3.0/24` or
      `2606:4700:4700::/48`). The API rejects private or unique-local, loopback,
      link-local, unspecified, and IPv4 broadcast addresses, including their
      IPv4-mapped IPv6 equivalents.
    - UNKNOWN: deprecated; you cannot use this when creating or updating policies,
      but it may appear on existing entries.
    """


class Post(BaseModel):
    """A blocked sender pattern."""

    id: Optional[str] = None
    """Blocked sender pattern identifier."""

    comments: Optional[str] = None

    created_at: Optional[datetime] = None

    is_regex: Optional[bool] = None

    last_modified: Optional[datetime] = None
    """Deprecated, use `modified_at` instead. End of life: November 1, 2026."""

    modified_at: Optional[datetime] = None

    pattern: Optional[str] = None
    """The pattern value to match.

    The format depends on `pattern_type`: a valid email address for EMAIL (e.g.
    `user@example.com`), a valid domain name for DOMAIN (e.g. `example.com`), or a
    plain IPv4 or IPv6 address or CIDR block for IP (e.g. `1.2.3.4`, `1.2.3.0/24`,
    `2606:4700:4700::1111`, or `2606:4700:4700::/48`); the API rejects private or
    unique-local, loopback, link-local, unspecified, and IPv4 broadcast addresses,
    including their IPv4-mapped IPv6 equivalents.
    """

    pattern_type: Optional[Literal["EMAIL", "DOMAIN", "IP", "UNKNOWN"]] = None
    """Type of pattern matching.

    - EMAIL: matches a full email address (e.g. `user@example.com`)
    - DOMAIN: matches a domain name (e.g. `example.com`)
    - IP: matches a plain IPv4 or IPv6 address (e.g. `1.2.3.4` or
      `2606:4700:4700::1111`) or CIDR block (e.g. `1.2.3.0/24` or
      `2606:4700:4700::/48`). The API rejects private or unique-local, loopback,
      link-local, unspecified, and IPv4 broadcast addresses, including their
      IPv4-mapped IPv6 equivalents.
    - UNKNOWN: deprecated; you cannot use this when creating or updating policies,
      but it may appear on existing entries.
    """


class Put(BaseModel):
    """A blocked sender pattern."""

    id: Optional[str] = None
    """Blocked sender pattern identifier."""

    comments: Optional[str] = None

    created_at: Optional[datetime] = None

    is_regex: Optional[bool] = None

    last_modified: Optional[datetime] = None
    """Deprecated, use `modified_at` instead. End of life: November 1, 2026."""

    modified_at: Optional[datetime] = None

    pattern: Optional[str] = None
    """The pattern value to match.

    The format depends on `pattern_type`: a valid email address for EMAIL (e.g.
    `user@example.com`), a valid domain name for DOMAIN (e.g. `example.com`), or a
    plain IPv4 or IPv6 address or CIDR block for IP (e.g. `1.2.3.4`, `1.2.3.0/24`,
    `2606:4700:4700::1111`, or `2606:4700:4700::/48`); the API rejects private or
    unique-local, loopback, link-local, unspecified, and IPv4 broadcast addresses,
    including their IPv4-mapped IPv6 equivalents.
    """

    pattern_type: Optional[Literal["EMAIL", "DOMAIN", "IP", "UNKNOWN"]] = None
    """Type of pattern matching.

    - EMAIL: matches a full email address (e.g. `user@example.com`)
    - DOMAIN: matches a domain name (e.g. `example.com`)
    - IP: matches a plain IPv4 or IPv6 address (e.g. `1.2.3.4` or
      `2606:4700:4700::1111`) or CIDR block (e.g. `1.2.3.0/24` or
      `2606:4700:4700::/48`). The API rejects private or unique-local, loopback,
      link-local, unspecified, and IPv4 broadcast addresses, including their
      IPv4-mapped IPv6 equivalents.
    - UNKNOWN: deprecated; you cannot use this when creating or updating policies,
      but it may appear on existing entries.
    """


class BlockSenderBatchResponse(BaseModel):
    deletes: Optional[List[Delete]] = None

    patches: Optional[List[Patch]] = None

    posts: Optional[List[Post]] = None

    puts: Optional[List[Put]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ...._models import BaseModel

__all__ = ["VersionListResponse"]


class VersionListResponse(BaseModel):
    id: Optional[int] = None
    """Unique identifier for this version."""

    created_at: Optional[datetime] = None
    """When this version was created (RFC 3339)."""

    version: Optional[int] = None
    """Sequential version number."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .dnssec import DNSSEC as DNSSEC
from .zsk_list_response import ZskListResponse as ZskListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["CheckRegion"]

CheckRegion: TypeAlias = Literal[
    "WNAM",
    "ENAM",
    "WEU",
    "EEU",
    "NSAM",
    "SSAM",
    "OC",
    "ME",
    "NAF",
    "SAF",
    "SAS",
    "SEAS",
    "NEAS",
    "CHINA",
    "ALL_REGIONS",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Required, TypedDict

__all__ = ["DatasetUpdateParams", "Field"]


class DatasetUpdateParams(TypedDict, total=False):
    enabled: Required[bool]
    """Whether to enable or disable log ingest for this dataset."""

    account_id: str
    """The Account ID to use for this endpoint. Mutually exclusive with the Zone ID."""

    zone_id: str
    """The Zone ID to use for this endpoint. Mutually exclusive with the Account ID."""

    deletion_protection: bool
    """Set to `false` to allow deletion of this dataset."""

    fields: Iterable[Field]
    """Controls which fields the API ingests after the update.

    Defaults to all available fields when absent.
    """

    filter: Optional[str]
    """Optional Logpush filter predicate to restrict which events are ingested.

    If omitted, the existing filter is left unchanged. Set to an empty string (`""`)
    to clear the filter. Otherwise, replaces the dataset's filter entirely. See
    [Logpush filters](https://developers.cloudflare.com/logs/reference/filters/) for
    syntax and examples.
    """


class Field(TypedDict, total=False):
    enabled: Required[bool]
    """Whether the API includes this field in log ingest."""

    name: Required[str]
    """Field name in lowercase."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Required, TypedDict

from ....._types import SequenceNotStr
from ..split_tunnel_exclude_param import SplitTunnelExcludeParam
from ..split_tunnel_include_param import SplitTunnelIncludeParam

__all__ = ["DefaultEditParams", "DNSSearchSuffix", "GlobalAcceleration", "ServiceModeV2", "VirtualNetworks"]


class DefaultEditParams(TypedDict, total=False):
    account_id: Required[str]

    allow_mode_switch: bool
    """Whether to allow the user to switch WARP between modes."""

    allow_updates: bool
    """
    Whether to receive update notifications when a new version of the client is
    available.
    """

    allowed_to_leave: bool
    """Whether to allow devices to leave the organization."""

    auto_connect: float
    """The amount of time in seconds to reconnect after having been disabled."""

    captive_portal: float
    """Turn on the captive portal after the specified amount of time."""

    disable_auto_fallback: bool
    """
    If the `dns_server` field of a fallback domain is not present, the client will
    fall back to a best guess of the default/system DNS resolvers unless this policy
    option is set to `true`.
    """

    dns_search_suffixes: Iterable[DNSSearchSuffix]
    """List of DNS search suffixes to apply to clients.

    Suffixes are evaluated in order. Use an empty array to clear.
    """

    exclude: Iterable[SplitTunnelExcludeParam]
    """List of routes excluded in the WARP client's tunnel.

    Both 'exclude' and 'include' cannot be set in the same request.
    """

    exclude_office_ips: bool
    """Whether to add Microsoft IPs to Split Tunnel exclusions."""

    global_acceleration: Optional[GlobalAcceleration]
    """Global Acceleration settings for China.

    When configured, WARP clients connect to the Global Accelerator addresses
    instead of the default ones. Please contact your account representative to
    enable this feature on your account. See
    https://developers.cloudflare.com/china-network/concepts/global-acceleration/.
    """

    include: Iterable[SplitTunnelIncludeParam]
    """List of routes included in the WARP client's tunnel.

    Both 'exclude' and 'include' cannot be set in the same request.
    """

    lan_allow_minutes: float
    """The amount of time in minutes a user is allowed access to their LAN.

    A value of 0 will allow LAN access until the next WARP reconnection, such as a
    reboot or a laptop waking from sleep. Note that this field is omitted from the
    response if null or unset.
    """

    lan_allow_subnet_size: float
    """The size of the subnet for the local access network.

    Note that this field is omitted from the response if null or unset.
    """

    register_interface_ip_with_dns: bool
    """
    Determines if the operating system will register WARP's local interface IP with
    your on-premises DNS server.
    """

    sccm_vpn_boundary_support: bool
    """
    Determines whether the WARP client indicates to SCCM that it is inside a VPN
    boundary. (Windows only).
    """

    service_mode_v2: ServiceModeV2

    support_url: str
    """The URL to launch when the Send Feedback button is clicked."""

    switch_locked: bool
    """
    Whether to allow the user to turn off the WARP switch and disconnect the client.
    """

    tunnel_protocol: str
    """Determines which tunnel protocol to use."""

    virtual_networks: Optional[VirtualNetworks]
    """Virtual network access settings for the device."""


class DNSSearchSuffix(TypedDict, total=False):
    suffix: Required[str]
    """The DNS search suffix to append when resolving short hostnames."""

    description: str
    """A description of the DNS search suffix."""


class GlobalAcceleration(TypedDict, total=False):
    """Global Acceleration settings for China.

    When configured, WARP clients connect to the Global Accelerator addresses instead of the default ones. Please contact your account representative to enable this feature on your account. See https://developers.cloudflare.com/china-network/concepts/global-acceleration/.
    """

    api_endpoints: Required[SequenceNotStr[str]]
    """IP:port entries for the API endpoints."""

    enabled: Required[bool]
    """Global acceleration settings are used only when "enabled"."""

    masque_endpoints: Required[SequenceNotStr[str]]
    """IP:port entries for the MASQUE tunnel endpoints.

    Either wireguard_endpoints or masque_endpoints must be provided.
    """

    wireguard_endpoints: Required[SequenceNotStr[str]]
    """IP:port entries for the WireGuard tunnel endpoints.

    Either wireguard_endpoints or masque_endpoints must be provided.
    """


class ServiceModeV2(TypedDict, total=False):
    mode: str
    """The mode to run the WARP client under."""

    port: float
    """The port number when used with proxy mode."""


class VirtualNetworks(TypedDict, total=False):
    """Virtual network access settings for the device."""

    allowed: Required[SequenceNotStr[str]]
    """List of virtual network IDs the device is allowed to access.

    When virtual_networks is set, at least one entry is required.
    """

    default: Required[str]
    """The default virtual network ID. Must be included in the `allowed` list."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["UsageGetAccountUsageV1Response", "UsageGetAccountUsageV1ResponseItem"]


class UsageGetAccountUsageV1ResponseItem(BaseModel):
    """Represents a single billable usage record.

    This schema carries 19 of the 21 columns FOCUS 1.3 marks as mandatory. Mandatory columns are always present, using an explicit null when the value is unknown, so consumers can distinguish "unknown" from "not provided".

    Known gap 1: `ServiceCategory` (FOCUS 1.3 section 3.1.55) is not yet implemented and does not appear in this schema. Cloudflare's product catalog does not yet have a stakeholder-approved mapping from product family to a FOCUS ServiceCategory value, so the column is omitted entirely rather than shipping unapproved values. It will be added once that mapping exists.

    Known gap 2: `BillingPeriodEnd` (FOCUS 1.3 section 3.1.4) is not yet implemented and does not appear in this schema, because no authoritative source for it exists today. Deriving it by calendar arithmetic drifts for billing cycle anchors on day 29-31, and the billing provider's current period end describes only the current period, so it is wrong for backdated records. `BillingPeriodStart` is correctly sourced and is still reported, so records carry a billing period start with no corresponding end until an authoritative end date is available.

    Per FOCUS 1.3 section 4.1.4.1, the columns that are not part of FOCUS (`ServiceFamilyName`, `CumulatedPricingQuantity`, `CumulatedContractedCost`, `ZoneId`, `ZoneName` and `SubscriptionId`) would normally carry an `x_` prefix. They are kept unprefixed here to avoid a breaking change for existing consumers.
    """

    billed_cost: float = FieldInfo(alias="BilledCost")
    """The amount invoiced for this charge.

    PayGo is billed directly by Cloudflare, so this equals ContractedCost.
    """

    billing_account_id: str = FieldInfo(alias="BillingAccountId")
    """The identifier of the account the charge is billed to (account tag)."""

    billing_account_name: Optional[str] = FieldInfo(alias="BillingAccountName", default=None)
    """The display name of the billing account.

    Null when the name could not be resolved.
    """

    billing_currency: str = FieldInfo(alias="BillingCurrency")
    """Specifies the billing currency code (ISO 4217)."""

    billing_period_start: datetime = FieldInfo(alias="BillingPeriodStart")
    """Indicates the start of the billing period.

    There is no `BillingPeriodEnd` counterpart; see the known gaps described on this
    schema.
    """

    charge_category: Literal["Usage"] = FieldInfo(alias="ChargeCategory")
    """Describes the nature of the charge.

    Always "Usage" for this endpoint, which only returns metered usage.
    """

    charge_class: Optional[str] = FieldInfo(alias="ChargeClass", default=None)
    """Indicates whether the row corrects a previously invoiced billing period.

    Always null for this endpoint, which does not return corrections.
    """

    charge_description: Optional[str] = FieldInfo(alias="ChargeDescription", default=None)
    """A human-readable summary of the charge."""

    charge_period_end: datetime = FieldInfo(alias="ChargePeriodEnd")
    """Indicates the end of the charge period."""

    charge_period_start: datetime = FieldInfo(alias="ChargePeriodStart")
    """Indicates the start of the charge period."""

    consumed_quantity: float = FieldInfo(alias="ConsumedQuantity")
    """Specifies the quantity consumed during this charge period."""

    consumed_unit: str = FieldInfo(alias="ConsumedUnit")
    """
    A display name for the unit of measurement used for the product (for example,
    "GB-months", "GB-seconds"). May be empty when the unit is implicit in the
    service name.
    """

    contracted_cost: float = FieldInfo(alias="ContractedCost")
    """Specifies the cost for this charge period in the billing currency."""

    cumulated_contracted_cost: float = FieldInfo(alias="CumulatedContractedCost")
    """Specifies the cumulated cost for the billing period in the billing currency."""

    cumulated_pricing_quantity: int = FieldInfo(alias="CumulatedPricingQuantity")
    """Specifies the portion of usage that is actually subject to a unit price."""

    effective_cost: float = FieldInfo(alias="EffectiveCost")
    """The amortized cost of the charge.

    PayGo has no upfront commitments, so this equals ContractedCost.
    """

    host_provider_name: str = FieldInfo(alias="HostProviderName")
    """The provider that hosts the infrastructure or platform the service runs on."""

    invoice_issuer_name: str = FieldInfo(alias="InvoiceIssuerName")
    """The entity that issues the invoice for this charge."""

    list_cost: float = FieldInfo(alias="ListCost")
    """The cost at published list prices, before any discount.

    PayGo has no commitment discounts, so this equals ContractedCost.
    """

    pricing_quantity: int = FieldInfo(alias="PricingQuantity")
    """Specifies the pricing quantity for this charge period."""

    pricing_unit: str = FieldInfo(alias="PricingUnit")
    """The unit that PricingQuantity is expressed in.

    Unlike ConsumedUnit this is never empty; it falls back to "Count" when the
    service has no explicit unit.
    """

    service_name: str = FieldInfo(alias="ServiceName")
    """Identifies the Cloudflare service."""

    service_provider_name: str = FieldInfo(alias="ServiceProviderName")
    """The provider of the purchased service."""

    service_family_name: Optional[str] = FieldInfo(alias="ServiceFamilyName", default=None)
    """Identifies the product family for the Cloudflare service."""

    subscription_id: Optional[str] = FieldInfo(alias="SubscriptionId", default=None)
    """The identifier for the Cloudflare subscription."""

    zone_id: Optional[str] = FieldInfo(alias="ZoneId", default=None)
    """The identifier for the Cloudflare zone (zone tag)."""

    zone_name: Optional[str] = FieldInfo(alias="ZoneName", default=None)
    """The display name of the Cloudflare zone."""


UsageGetAccountUsageV1Response: TypeAlias = List[UsageGetAccountUsageV1ResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ....._models import BaseModel

__all__ = ["TailCreateResponse"]


class TailCreateResponse(BaseModel):
    """A tail session for streaming logs from a Pages deployment."""

    id: str
    """Identifier of the tail session."""

    url: Optional[str] = None
    """
    Optional WebSocket URL to connect to for receiving tail events, when returned by
    the tail service.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["RulesetDeleteParams"]


class RulesetDeleteParams(TypedDict, total=False):
    account_id: str
    """The Account ID to use for this endpoint. Mutually exclusive with the Zone ID."""

    zone_id: str
    """The Zone ID to use for this endpoint. Mutually exclusive with the Account ID."""

    dry_run: bool
    """Validates the request without persisting changes when set to `true`.

    Responses that normally return 200 return `result: null`; endpoints that
    normally return 204 continue to return 204.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["WorkflowGetResponse", "Schedule"]


class Schedule(BaseModel):
    cron: str

    next_instance: str


class WorkflowGetResponse(BaseModel):
    id: str

    class_name: str

    created_on: datetime

    instances: Dict[str, float]

    modified_on: datetime

    name: str

    script_name: str

    triggered_on: Optional[datetime] = None

    schedules: Optional[List[Schedule]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["ContentPolicyCreateParams"]


class ContentPolicyCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    enabled: Required[bool]

    name: Required[str]

    pattern: Required[str]

    targets: Required[List[Literal["SUBJECT", "BODY"]]]

    notes: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .zones import (
    ZonesResource,
    AsyncZonesResource,
    ZonesResourceWithRawResponse,
    AsyncZonesResourceWithRawResponse,
    ZonesResourceWithStreamingResponse,
    AsyncZonesResourceWithStreamingResponse,
)
from .spectrum_analytics import (
    SpectrumAnalyticsResource,
    AsyncSpectrumAnalyticsResource,
    SpectrumAnalyticsResourceWithRawResponse,
    AsyncSpectrumAnalyticsResourceWithRawResponse,
    SpectrumAnalyticsResourceWithStreamingResponse,
    AsyncSpectrumAnalyticsResourceWithStreamingResponse,
)

__all__ = [
    "ZonesResource",
    "AsyncZonesResource",
    "ZonesResourceWithRawResponse",
    "AsyncZonesResourceWithRawResponse",
    "ZonesResourceWithStreamingResponse",
    "AsyncZonesResourceWithStreamingResponse",
    "SpectrumAnalyticsResource",
    "AsyncSpectrumAnalyticsResource",
    "SpectrumAnalyticsResourceWithRawResponse",
    "AsyncSpectrumAnalyticsResourceWithRawResponse",
    "SpectrumAnalyticsResourceWithStreamingResponse",
    "AsyncSpectrumAnalyticsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import path_template
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncSinglePage, AsyncSinglePage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.spectrum.protocol_list_response import ProtocolListResponse

__all__ = ["ProtocolsResource", "AsyncProtocolsResource"]


class ProtocolsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ProtocolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ProtocolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProtocolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ProtocolsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[ProtocolListResponse]:
        """
        Retrieves a list of Spectrum application protocols available for a zone.

        Args:
          zone_id: Zone identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/spectrum/protocols", zone_id=zone_id),
            page=SyncSinglePage[ProtocolListResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=ProtocolListResponse,
        )


class AsyncProtocolsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncProtocolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncProtocolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProtocolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncProtocolsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[ProtocolListResponse, AsyncSinglePage[ProtocolListResponse]]:
        """
        Retrieves a list of Spectrum application protocols available for a zone.

        Args:
          zone_id: Zone identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/spectrum/protocols", zone_id=zone_id),
            page=AsyncSinglePage[ProtocolListResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=ProtocolListResponse,
        )


class ProtocolsResourceWithRawResponse:
    def __init__(self, protocols: ProtocolsResource) -> None:
        self._protocols = protocols

        self.list = to_raw_response_wrapper(
            protocols.list,
        )


class AsyncProtocolsResourceWithRawResponse:
    def __init__(self, protocols: AsyncProtocolsResource) -> None:
        self._protocols = protocols

        self.list = async_to_raw_response_wrapper(
            protocols.list,
        )


class ProtocolsResourceWithStreamingResponse:
    def __init__(self, protocols: ProtocolsResource) -> None:
        self._protocols = protocols

        self.list = to_streamed_response_wrapper(
            protocols.list,
        )


class AsyncProtocolsResourceWithStreamingResponse:
    def __init__(self, protocols: AsyncProtocolsResource) -> None:
        self._protocols = protocols

        self.list = async_to_streamed_response_wrapper(
            protocols.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .path_list_params import PathListParams as PathListParams
from .path_list_response import PathListResponse as PathListResponse
from .upstream_timeseries_params import UpstreamTimeseriesParams as UpstreamTimeseriesParams
from .upstream_timeseries_response import UpstreamTimeseriesResponse as UpstreamTimeseriesResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ...._base_client import make_request_options
from ....types.zones.ct import alerting_edit_params
from ....types.zones.ct.ct_alerting_subscription import CTAlertingSubscription

__all__ = ["AlertingResource", "AsyncAlertingResource"]


class AlertingResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AlertingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AlertingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AlertingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AlertingResourceWithStreamingResponse(self)

    def edit(
        self,
        *,
        zone_id: str,
        enabled: bool,
        emails: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CTAlertingSubscription]:
        """
        Create or update the Certificate Transparency alerting subscription for a zone.
        Enables or disables email notifications when certificates are issued for the
        zone's domains. The `enabled` field is required on every request and controls
        whether the subscription is active. The `emails` field is optional and, when
        provided, replaces the stored recipient list for the zone. When `emails` is
        omitted, the stored recipient list is preserved and only the enabled state is
        toggled. A maximum of 100 email addresses may be configured per zone. Requests
        that omit `enabled` are rejected with error code 1008. Subscribe and unsubscribe
        notification emails are only sent for recipients whose effective subscription
        state changes. Idempotent requests (no state change) send no notification email.

        Args:
          zone_id: Identifier.

          enabled: Whether CT alerting is enabled for the zone.

          emails: Email addresses that receive CT alert notifications for the zone. A maximum of
              100 addresses may be configured. Each address must be a valid RFC 5322 email
              address and must not contain a comma.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._patch(
            path_template("/zones/{zone_id}/ct/alerting", zone_id=zone_id),
            body=maybe_transform(
                {
                    "enabled": enabled,
                    "emails": emails,
                },
                alerting_edit_params.AlertingEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CTAlertingSubscription]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CTAlertingSubscription]], ResultWrapper[CTAlertingSubscription]),
        )

    def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CTAlertingSubscription]:
        """
        Retrieve the Certificate Transparency alerting subscription settings for a zone.
        Returns whether CT monitoring is enabled and the list of email addresses that
        receive alerts, if any have been configured.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get(
            path_template("/zones/{zone_id}/ct/alerting", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CTAlertingSubscription]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CTAlertingSubscription]], ResultWrapper[CTAlertingSubscription]),
        )


class AsyncAlertingResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAlertingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAlertingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAlertingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncAlertingResourceWithStreamingResponse(self)

    async def edit(
        self,
        *,
        zone_id: str,
        enabled: bool,
        emails: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CTAlertingSubscription]:
        """
        Create or update the Certificate Transparency alerting subscription for a zone.
        Enables or disables email notifications when certificates are issued for the
        zone's domains. The `enabled` field is required on every request and controls
        whether the subscription is active. The `emails` field is optional and, when
        provided, replaces the stored recipient list for the zone. When `emails` is
        omitted, the stored recipient list is preserved and only the enabled state is
        toggled. A maximum of 100 email addresses may be configured per zone. Requests
        that omit `enabled` are rejected with error code 1008. Subscribe and unsubscribe
        notification emails are only sent for recipients whose effective subscription
        state changes. Idempotent requests (no state change) send no notification email.

        Args:
          zone_id: Identifier.

          enabled: Whether CT alerting is enabled for the zone.

          emails: Email addresses that receive CT alert notifications for the zone. A maximum of
              100 addresses may be configured. Each address must be a valid RFC 5322 email
              address and must not contain a comma.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._patch(
            path_template("/zones/{zone_id}/ct/alerting", zone_id=zone_id),
            body=await async_maybe_transform(
                {
                    "enabled": enabled,
                    "emails": emails,
                },
                alerting_edit_params.AlertingEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CTAlertingSubscription]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CTAlertingSubscription]], ResultWrapper[CTAlertingSubscription]),
        )

    async def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CTAlertingSubscription]:
        """
        Retrieve the Certificate Transparency alerting subscription settings for a zone.
        Returns whether CT monitoring is enabled and the list of email addresses that
        receive alerts, if any have been configured.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._get(
            path_template("/zones/{zone_id}/ct/alerting", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CTAlertingSubscription]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CTAlertingSubscription]], ResultWrapper[CTAlertingSubscription]),
        )


class AlertingResourceWithRawResponse:
    def __init__(self, alerting: AlertingResource) -> None:
        self._alerting = alerting

        self.edit = to_raw_response_wrapper(
            alerting.edit,
        )
        self.get = to_raw_response_wrapper(
            alerting.get,
        )


class AsyncAlertingResourceWithRawResponse:
    def __init__(self, alerting: AsyncAlertingResource) -> None:
        self._alerting = alerting

        self.edit = async_to_raw_response_wrapper(
            alerting.edit,
        )
        self.get = async_to_raw_response_wrapper(
            alerting.get,
        )


class AlertingResourceWithStreamingResponse:
    def __init__(self, alerting: AlertingResource) -> None:
        self._alerting = alerting

        self.edit = to_streamed_response_wrapper(
            alerting.edit,
        )
        self.get = to_streamed_response_wrapper(
            alerting.get,
        )


class AsyncAlertingResourceWithStreamingResponse:
    def __init__(self, alerting: AsyncAlertingResource) -> None:
        self._alerting = alerting

        self.edit = async_to_streamed_response_wrapper(
            alerting.edit,
        )
        self.get = async_to_streamed_response_wrapper(
            alerting.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ...._models import BaseModel

__all__ = ["IngressCreateResponse"]


class IngressCreateResponse(BaseModel):
    id: Optional[str] = None
    """The unique identifier for the ingress rule."""

    cidr: Optional[str] = None
    """The CIDR block for the ingress rule."""

    created_on: Optional[datetime] = None
    """The date and time when the ingress rule was created."""

    modified_on: Optional[datetime] = None
    """The date and time when the ingress rule was last modified."""

    sinkhole_id: Optional[str] = None
    """The sinkhole this ingress rule belongs to."""

    zone_tag: Optional[str] = None
    """The zone tag associated with this ingress rule."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["SecretEditResponse"]


class SecretEditResponse(BaseModel):
    id: str
    """Secret identifier tag."""

    created: datetime
    """When the secret was created."""

    modified: datetime
    """When the secret was modified."""

    name: str
    """The name of the secret."""

    status: Literal["pending", "active", "deleted"]

    store_id: str
    """Store Identifier."""

    comment: Optional[str] = None
    """Freeform text describing the secret."""

    scopes: Optional[List[Literal["workers", "ai_gateway", "dex", "access", "containers", "websearch"]]] = None
    """The list of services that can use this secret."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Iterable, Optional, cast
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ..._base_client import make_request_options
from ...types.precursor import precursor_update_params
from ...types.precursor.precursor_config import PrecursorConfig
from ...types.precursor.enforcement_rule_param import EnforcementRuleParam

__all__ = ["PrecursorResource", "AsyncPrecursorResource"]


class PrecursorResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PrecursorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return PrecursorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PrecursorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return PrecursorResourceWithStreamingResponse(self)

    def update(
        self,
        *,
        zone_id: str,
        default_mode: Literal["off", "min-friction", "max-security"] | Omit = omit,
        enforcement_rules: Iterable[EnforcementRuleParam] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[PrecursorConfig]:
        """
        Updates the Precursor configuration for a zone.

        `default_mode` sets the zone-level enforcement mode. `enforcement_rules` is the
        ordered list of rules that override enforcement for matching requests.

        This is a partial update: only the fields present in the request body are
        changed.

        - Sending an empty array (`[]`) clears all enforcement rules.
        - At least one of `default_mode` or `enforcement_rules` must be present; an
          empty body (`{}`) is rejected with `400`.
        - Rule `id` is read-only (assigned by Cloudflare) and ignored on input.
        - Rule `mode` must be `min-friction` or `max-security` (`off` is not a valid
          rule mode; use `default_mode` to disable enforcement).
        - Rule `expression` is limited to 4000 characters. The limit applies to each
          rule individually, not to the combined size of all rules.

        Args:
          zone_id: Identifier.

          default_mode: The zone-level Precursor enforcement mode applied to requests that do not match
              a more specific enforcement rule.

          enforcement_rules: The ordered list of enforcement rules for the zone.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._put(
            path_template("/zones/{zone_id}/precursor", zone_id=zone_id),
            body=maybe_transform(
                {
                    "default_mode": default_mode,
                    "enforcement_rules": enforcement_rules,
                },
                precursor_update_params.PrecursorUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[PrecursorConfig]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[PrecursorConfig]], ResultWrapper[PrecursorConfig]),
        )

    def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[PrecursorConfig]:
        """
        Retrieve a zone's Precursor configuration: the zone-level `default_mode` and the
        ordered list of `enforcement_rules`.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get(
            path_template("/zones/{zone_id}/precursor", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[PrecursorConfig]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[PrecursorConfig]], ResultWrapper[PrecursorConfig]),
        )


class AsyncPrecursorResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPrecursorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPrecursorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPrecursorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncPrecursorResourceWithStreamingResponse(self)

    async def update(
        self,
        *,
        zone_id: str,
        default_mode: Literal["off", "min-friction", "max-security"] | Omit = omit,
        enforcement_rules: Iterable[EnforcementRuleParam] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[PrecursorConfig]:
        """
        Updates the Precursor configuration for a zone.

        `default_mode` sets the zone-level enforcement mode. `enforcement_rules` is the
        ordered list of rules that override enforcement for matching requests.

        This is a partial update: only the fields present in the request body are
        changed.

        - Sending an empty array (`[]`) clears all enforcement rules.
        - At least one of `default_mode` or `enforcement_rules` must be present; an
          empty body (`{}`) is rejected with `400`.
        - Rule `id` is read-only (assigned by Cloudflare) and ignored on input.
        - Rule `mode` must be `min-friction` or `max-security` (`off` is not a valid
          rule mode; use `default_mode` to disable enforcement).
        - Rule `expression` is limited to 4000 characters. The limit applies to each
          rule individually, not to the combined size of all rules.

        Args:
          zone_id: Identifier.

          default_mode: The zone-level Precursor enforcement mode applied to requests that do not match
              a more specific enforcement rule.

          enforcement_rules: The ordered list of enforcement rules for the zone.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._put(
            path_template("/zones/{zone_id}/precursor", zone_id=zone_id),
            body=await async_maybe_transform(
                {
                    "default_mode": default_mode,
                    "enforcement_rules": enforcement_rules,
                },
                precursor_update_params.PrecursorUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[PrecursorConfig]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[PrecursorConfig]], ResultWrapper[PrecursorConfig]),
        )

    async def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[PrecursorConfig]:
        """
        Retrieve a zone's Precursor configuration: the zone-level `default_mode` and the
        ordered list of `enforcement_rules`.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._get(
            path_template("/zones/{zone_id}/precursor", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[PrecursorConfig]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[PrecursorConfig]], ResultWrapper[PrecursorConfig]),
        )


class PrecursorResourceWithRawResponse:
    def __init__(self, precursor: PrecursorResource) -> None:
        self._precursor = precursor

        self.update = to_raw_response_wrapper(
            precursor.update,
        )
        self.get = to_raw_response_wrapper(
            precursor.get,
        )


class AsyncPrecursorResourceWithRawResponse:
    def __init__(self, precursor: AsyncPrecursorResource) -> None:
        self._precursor = precursor

        self.update = async_to_raw_response_wrapper(
            precursor.update,
        )
        self.get = async_to_raw_response_wrapper(
            precursor.get,
        )


class PrecursorResourceWithStreamingResponse:
    def __init__(self, precursor: PrecursorResource) -> None:
        self._precursor = precursor

        self.update = to_streamed_response_wrapper(
            precursor.update,
        )
        self.get = to_streamed_response_wrapper(
            precursor.get,
        )


class AsyncPrecursorResourceWithStreamingResponse:
    def __init__(self, precursor: AsyncPrecursorResource) -> None:
        self._precursor = precursor

        self.update = async_to_streamed_response_wrapper(
            precursor.update,
        )
        self.get = async_to_streamed_response_wrapper(
            precursor.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["RegistrationEditResponse", "Links", "Error"]


class Links(BaseModel):
    self: str
    """URL to this status resource."""

    resource: Optional[str] = None
    """URL to the domain resource."""


class Error(BaseModel):
    """Provides error details when a workflow reaches the `failed` state.

    The workflow type (registration, update, etc.) and underlying registry response determine the specific codes and messages. Workflow error codes differ from immediate HTTP error `errors[].code` values in non-2xx responses. Surface `error.message` to the user for context.
    """

    code: str
    """Machine-readable error code identifying the failure reason."""

    message: str
    """Human-readable explanation of the failure.

    May include registry-specific details.
    """


class RegistrationEditResponse(BaseModel):
    """Status of an async registration workflow."""

    completed: bool
    """Indicates whether the workflow reached a terminal state.

    A `succeeded` or `failed` state returns `true`; `pending`, `in_progress`,
    `action_required`, and `blocked` return `false`.
    """

    created_at: datetime

    links: Links

    state: Literal["pending", "in_progress", "action_required", "blocked", "succeeded", "failed"]
    """Describes the workflow lifecycle state.

    - `pending`: The workflow awaits processing.
    - `in_progress`: Processing started. Continue polling `links.self`. An internal
      deadline limits the duration of this state.
    - `action_required`: The workflow pauses for user action. See `context.action`
      for details. Stop automated polling until the user completes the required
      action.
    - `blocked`: A third party, such as the domain extension's registry or a losing
      registrar, prevents progress. Continue polling because the block may resolve
      when the third party responds.
    - `succeeded`: Terminal state. The operation completed successfully. `completed`
      equals `true`. For registrations, `context.registration` contains the
      resulting registration resource.
    - `failed`: Terminal state. The operation failed. `completed` equals `true`. See
      `error.code` and `error.message` for the reason. Require user review before
      retrying.
    """

    updated_at: datetime

    context: Optional[Dict[str, object]] = None
    """Provides workflow-specific data.

    For domain-centric workflows, `context.domain_name` identifies the workflow
    subject.
    """

    error: Optional[Error] = None
    """Provides error details when a workflow reaches the `failed` state.

    The workflow type (registration, update, etc.) and underlying registry response
    determine the specific codes and messages. Workflow error codes differ from
    immediate HTTP error `errors[].code` values in non-2xx responses. Surface
    `error.message` to the user for context.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["RegistrarCheckResponse", "Domain", "DomainPricing"]


class DomainPricing(BaseModel):
    """Provides annual pricing information for a registrable domain.

    This object
    appears only when `registrable` is `true`. The API returns all per-year
    prices as strings to preserve decimal precision.

    `registration_cost` and `renewal_cost` frequently have the same value, but
    may differ, especially when registries set different premium rates for
    initial registration and renewal. For a multi-year registration (e.g., 4
    years), `registration_cost` applies to the first year and `renewal_cost`
    applies to each subsequent year. The values reflect the current registry
    rate, which may change over time. Search and Check may surface premium
    pricing, but this API currently supports standard registrations only.
    """

    currency: str
    """ISO-4217 currency code for the prices (e.g., "USD", "EUR", "GBP")."""

    registration_cost: str
    """The first-year cost to register this domain.

    For premium domains (`tier: premium`), the registry sets this price, which may
    significantly exceed standard pricing. For multi-year registrations, this cost
    applies to the first year only; `renewal_cost` applies to subsequent years.
    """

    renewal_cost: str
    """Per-year renewal cost for this domain.

    Applied to each year beyond the first year of a multi-year registration, and to
    each annual auto-renewal thereafter. May differ from `registration_cost`,
    especially for premium domains where initial registration often costs more than
    renewals.
    """


class Domain(BaseModel):
    """
    Describes a single authoritative domain availability result from the Check endpoint. Check results reflect current registry status; use them immediately before registration.
    """

    name: str
    """
    The fully qualified domain name (FQDN) in punycode format for internationalized
    domain names (IDNs).
    """

    registrable: bool
    """
    Indicates programmatic registration eligibility according to a real-time
    registry check.

    - `true`: The domain is available for registration. The response includes the
      `pricing` object.
    - `false`: A restriction prevents registration. See the `reason` field for
      details. Some results, such as premium domains, may still include `tier`.
    """

    pricing: Optional[DomainPricing] = None
    """Provides annual pricing information for a registrable domain.

    This object appears only when `registrable` is `true`. The API returns all
    per-year prices as strings to preserve decimal precision.

    `registration_cost` and `renewal_cost` frequently have the same value, but may
    differ, especially when registries set different premium rates for initial
    registration and renewal. For a multi-year registration (e.g., 4 years),
    `registration_cost` applies to the first year and `renewal_cost` applies to each
    subsequent year. The values reflect the current registry rate, which may change
    over time. Search and Check may surface premium pricing, but this API currently
    supports standard registrations only.
    """

    reason: Optional[
        Literal[
            "extension_not_supported_via_api",
            "extension_not_supported",
            "extension_disallows_registration",
            "domain_premium",
            "domain_unavailable",
        ]
    ] = None
    """Appears only when `registrable` is `false` and explains the result.

    - `extension_not_supported_via_api`: Cloudflare Registrar supports this
      extension in the dashboard but currently excludes it from programmatic
      registration through this API. The user can register via
      `https://dash.cloudflare.com/{account_id}/domains/registrations`.
    - `extension_not_supported`: Cloudflare Registrar excludes this extension
      entirely.
    - `extension_disallows_registration`: The extension's registry temporarily or
      permanently freezes new registrations. Registrars currently cannot register
      domains on this extension.
    - `domain_premium`: The domain carries premium pricing. This API currently
      supports standard registrations only.
    - `domain_unavailable`: An existing registration, reservation, or other registry
      restriction makes the domain unavailable on a supported extension.
    """

    tier: Optional[Literal["standard", "premium"]] = None
    """The pricing tier for this domain.

    A `registrable` value of `true` always includes this field, which defaults to
    `standard` for most domains. A `registrable` value of `false` may omit it.

    - `standard`: Standard registry pricing.
    - `premium`: Premium domain with higher pricing from the registry.
    """


class RegistrarCheckResponse(BaseModel):
    """Contains the availability check results."""

    domains: List[Domain]
    """Array of domain availability results.

    Results for unsupported extensions contain `registrable: false` and a `reason`
    field. The response may omit malformed domain names.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Type, Iterable, Optional, cast

import httpx

from ....._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ....._utils import path_template, maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._wrappers import ResultWrapper
from ....._base_client import make_request_options
from .....types.pages.projects.deployments import tail_create_params
from .....types.pages.projects.deployments.tail_create_response import TailCreateResponse

__all__ = ["TailsResource", "AsyncTailsResource"]


class TailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return TailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return TailsResourceWithStreamingResponse(self)

    def create(
        self,
        deployment_id: str,
        *,
        account_id: str,
        project_name: str,
        filters: Iterable[Dict[str, object]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TailCreateResponse:
        """
        Start a tail that receives logs and exception data.

        Args:
          account_id: Identifier.

          project_name: Name of the project.

          deployment_id: Identifier.

          filters: Filters to apply to the tail session.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not project_name:
            raise ValueError(f"Expected a non-empty value for `project_name` but received {project_name!r}")
        if not deployment_id:
            raise ValueError(f"Expected a non-empty value for `deployment_id` but received {deployment_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/pages/projects/{project_name}/deployments/{deployment_id}/tails",
                account_id=account_id,
                project_name=project_name,
                deployment_id=deployment_id,
            ),
            body=maybe_transform({"filters": filters}, tail_create_params.TailCreateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[TailCreateResponse]._unwrapper,
            ),
            cast_to=cast(Type[TailCreateResponse], ResultWrapper[TailCreateResponse]),
        )

    def delete(
        self,
        tail_id: str,
        *,
        account_id: str,
        project_name: str,
        deployment_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes a tail from a Pages deployment.

        Args:
          account_id: Identifier.

          project_name: Name of the project.

          deployment_id: Identifier.

          tail_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not project_name:
            raise ValueError(f"Expected a non-empty value for `project_name` but received {project_name!r}")
        if not deployment_id:
            raise ValueError(f"Expected a non-empty value for `deployment_id` but received {deployment_id!r}")
        if not tail_id:
            raise ValueError(f"Expected a non-empty value for `tail_id` but received {tail_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/pages/projects/{project_name}/deployments/{deployment_id}/tails/{tail_id}",
                account_id=account_id,
                project_name=project_name,
                deployment_id=deployment_id,
                tail_id=tail_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )


class AsyncTailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncTailsResourceWithStreamingResponse(self)

    async def create(
        self,
        deployment_id: str,
        *,
        account_id: str,
        project_name: str,
        filters: Iterable[Dict[str, object]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TailCreateResponse:
        """
        Start a tail that receives logs and exception data.

        Args:
          account_id: Identifier.

          project_name: Name of the project.

          deployment_id: Identifier.

          filters: Filters to apply to the tail session.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not project_name:
            raise ValueError(f"Expected a non-empty value for `project_name` but received {project_name!r}")
        if not deployment_id:
            raise ValueError(f"Expected a non-empty value for `deployment_id` but received {deployment_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/pages/projects/{project_name}/deployments/{deployment_id}/tails",
                account_id=account_id,
                project_name=project_name,
                deployment_id=deployment_id,
            ),
            body=await async_maybe_transform({"filters": filters}, tail_create_params.TailCreateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[TailCreateResponse]._unwrapper,
            ),
            cast_to=cast(Type[TailCreateResponse], ResultWrapper[TailCreateResponse]),
        )

    async def delete(
        self,
        tail_id: str,
        *,
        account_id: str,
        project_name: str,
        deployment_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes a tail from a Pages deployment.

        Args:
          account_id: Identifier.

          project_name: Name of the project.

          deployment_id: Identifier.

          tail_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not project_name:
            raise ValueError(f"Expected a non-empty value for `project_name` but received {project_name!r}")
        if not deployment_id:
            raise ValueError(f"Expected a non-empty value for `deployment_id` but received {deployment_id!r}")
        if not tail_id:
            raise ValueError(f"Expected a non-empty value for `tail_id` but received {tail_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/pages/projects/{project_name}/deployments/{deployment_id}/tails/{tail_id}",
                account_id=account_id,
                project_name=project_name,
                deployment_id=deployment_id,
                tail_id=tail_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )


class TailsResourceWithRawResponse:
    def __init__(self, tails: TailsResource) -> None:
        self._tails = tails

        self.create = to_raw_response_wrapper(
            tails.create,
        )
        self.delete = to_raw_response_wrapper(
            tails.delete,
        )


class AsyncTailsResourceWithRawResponse:
    def __init__(self, tails: AsyncTailsResource) -> None:
        self._tails = tails

        self.create = async_to_raw_response_wrapper(
            tails.create,
        )
        self.delete = async_to_raw_response_wrapper(
            tails.delete,
        )


class TailsResourceWithStreamingResponse:
    def __init__(self, tails: TailsResource) -> None:
        self._tails = tails

        self.create = to_streamed_response_wrapper(
            tails.create,
        )
        self.delete = to_streamed_response_wrapper(
            tails.delete,
        )


class AsyncTailsResourceWithStreamingResponse:
    def __init__(self, tails: AsyncTailsResource) -> None:
        self._tails = tails

        self.create = async_to_streamed_response_wrapper(
            tails.create,
        )
        self.delete = async_to_streamed_response_wrapper(
            tails.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["EnforcementRuleParam"]


class EnforcementRuleParam(TypedDict, total=False):
    expression: Required[str]
    """The filter expression that determines which requests the rule matches."""

    mode: Required[Literal["min-friction", "max-security"]]
    """The override mode Precursor applies to requests matching an enforcement rule.

    Unlike `default_mode`, this cannot be `off`.
    """

    description: str
    """An informative description of the rule."""

    enabled: bool
    """Whether the rule is active."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = ["PathListResponse", "ASNInfo", "Meta", "Path"]


class ASNInfo(BaseModel):
    asn: int
    """ASN number."""

    country: Optional[str] = None
    """Alpha-2 country code."""

    name: Optional[str] = None
    """AS name."""


class Meta(BaseModel):
    data_time: Optional[datetime] = FieldInfo(alias="dataTime", default=None)
    """Timestamp of the underlying RIB data."""

    effective_collector: Optional[str] = FieldInfo(alias="effectiveCollector", default=None)

    query_time: Optional[datetime] = FieldInfo(alias="queryTime", default=None)
    """Timestamp when the query was executed."""

    stale: bool


class Path(BaseModel):
    collectors: List[str]

    paths_count: int = FieldInfo(alias="pathsCount")

    peers_count: int = FieldInfo(alias="peersCount")

    segment: List[int]


class PathListResponse(BaseModel):
    asn_info: Optional[Dict[str, ASNInfo]] = FieldInfo(alias="asnInfo", default=None)

    collectors: List[str]

    meta: Meta

    paths: List[Path]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Iterable, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ..._base_client import make_request_options
from ...types.ai_security import custom_topic_update_params
from ...types.ai_security.custom_topic_get_response import CustomTopicGetResponse
from ...types.ai_security.custom_topic_update_response import CustomTopicUpdateResponse

__all__ = ["CustomTopicsResource", "AsyncCustomTopicsResource"]


class CustomTopicsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CustomTopicsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return CustomTopicsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CustomTopicsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return CustomTopicsResourceWithStreamingResponse(self)

    def update(
        self,
        *,
        zone_id: str,
        topics: Iterable[custom_topic_update_params.Topic] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CustomTopicUpdateResponse:
        """
        Update the custom topic list of the zone, overwriting it entirely with the
        topics in the request, so include every topic you want to keep. Changes can take
        up to a minute to propagate.

        Each entry has a `label`, used to reference the topic in rule expressions and
        analytics, and a `topic` description, which the classifier scores prompts
        against while AI Security for Apps is enabled. The following rules apply:

        - A zone can hold at most 20 topics.
        - `label` must be 2–20 characters, using only lowercase letters (a–z), digits
          (0–9), and hyphens.
        - `topic` must be 2–50 printable ASCII characters.
        - Labels must be unique within the zone, and so must topic descriptions.

        Args:
          zone_id: Defines the zone.

          topics: Custom topic categories for AI Security for Apps content detection.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._put(
            path_template("/zones/{zone_id}/ai-security/custom-topics", zone_id=zone_id),
            body=maybe_transform({"topics": topics}, custom_topic_update_params.CustomTopicUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CustomTopicUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[CustomTopicUpdateResponse], ResultWrapper[CustomTopicUpdateResponse]),
        )

    def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CustomTopicGetResponse:
        """Get the custom topic categories defined for the zone.

        While AI Security for Apps
        is enabled, it scores every incoming prompt against these topics and writes the
        scores to the `cf.llm.prompt.custom_topic_categories` field, keyed by topic
        label. Topics can be configured while the detection is disabled, but no prompt
        is scored until you enable it.

        Args:
          zone_id: Defines the zone.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get(
            path_template("/zones/{zone_id}/ai-security/custom-topics", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CustomTopicGetResponse]._unwrapper,
            ),
            cast_to=cast(Type[CustomTopicGetResponse], ResultWrapper[CustomTopicGetResponse]),
        )


class AsyncCustomTopicsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCustomTopicsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCustomTopicsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCustomTopicsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncCustomTopicsResourceWithStreamingResponse(self)

    async def update(
        self,
        *,
        zone_id: str,
        topics: Iterable[custom_topic_update_params.Topic] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CustomTopicUpdateResponse:
        """
        Update the custom topic list of the zone, overwriting it entirely with the
        topics in the request, so include every topic you want to keep. Changes can take
        up to a minute to propagate.

        Each entry has a `label`, used to reference the topic in rule expressions and
        analytics, and a `topic` description, which the classifier scores prompts
        against while AI Security for Apps is enabled. The following rules apply:

        - A zone can hold at most 20 topics.
        - `label` must be 2–20 characters, using only lowercase letters (a–z), digits
          (0–9), and hyphens.
        - `topic` must be 2–50 printable ASCII characters.
        - Labels must be unique within the zone, and so must topic descriptions.

        Args:
          zone_id: Defines the zone.

          topics: Custom topic categories for AI Security for Apps content detection.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._put(
            path_template("/zones/{zone_id}/ai-security/custom-topics", zone_id=zone_id),
            body=await async_maybe_transform({"topics": topics}, custom_topic_update_params.CustomTopicUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CustomTopicUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[CustomTopicUpdateResponse], ResultWrapper[CustomTopicUpdateResponse]),
        )

    async def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CustomTopicGetResponse:
        """Get the custom topic categories defined for the zone.

        While AI Security for Apps
        is enabled, it scores every incoming prompt against these topics and writes the
        scores to the `cf.llm.prompt.custom_topic_categories` field, keyed by topic
        label. Topics can be configured while the detection is disabled, but no prompt
        is scored until you enable it.

        Args:
          zone_id: Defines the zone.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._get(
            path_template("/zones/{zone_id}/ai-security/custom-topics", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CustomTopicGetResponse]._unwrapper,
            ),
            cast_to=cast(Type[CustomTopicGetResponse], ResultWrapper[CustomTopicGetResponse]),
        )


class CustomTopicsResourceWithRawResponse:
    def __init__(self, custom_topics: CustomTopicsResource) -> None:
        self._custom_topics = custom_topics

        self.update = to_raw_response_wrapper(
            custom_topics.update,
        )
        self.get = to_raw_response_wrapper(
            custom_topics.get,
        )


class AsyncCustomTopicsResourceWithRawResponse:
    def __init__(self, custom_topics: AsyncCustomTopicsResource) -> None:
        self._custom_topics = custom_topics

        self.update = async_to_raw_response_wrapper(
            custom_topics.update,
        )
        self.get = async_to_raw_response_wrapper(
            custom_topics.get,
        )


class CustomTopicsResourceWithStreamingResponse:
    def __init__(self, custom_topics: CustomTopicsResource) -> None:
        self._custom_topics = custom_topics

        self.update = to_streamed_response_wrapper(
            custom_topics.update,
        )
        self.get = to_streamed_response_wrapper(
            custom_topics.get,
        )


class AsyncCustomTopicsResourceWithStreamingResponse:
    def __init__(self, custom_topics: AsyncCustomTopicsResource) -> None:
        self._custom_topics = custom_topics

        self.update = async_to_streamed_response_wrapper(
            custom_topics.update,
        )
        self.get = async_to_streamed_response_wrapper(
            custom_topics.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ...._base_client import make_request_options
from ....types.logpush.transformers import content_get_params
from ....types.logpush.transformers.content_get_response import ContentGetResponse

__all__ = ["ContentResource", "AsyncContentResource"]


class ContentResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ContentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ContentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ContentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ContentResourceWithStreamingResponse(self)

    def get(
        self,
        transformer_id: int,
        *,
        account_id: str,
        version_id: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentGetResponse]:
        """Returns the SQL query content for a transformer.

        Without query params, returns
        the latest version. With `version_id`, returns the specified version.

        Args:
          account_id: Identifier.

          transformer_id: The transformer ID.

          version_id: Specific version ID to retrieve. When omitted, the latest version is returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/logpush/transformers/{transformer_id}/content",
                account_id=account_id,
                transformer_id=transformer_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"version_id": version_id}, content_get_params.ContentGetParams),
                post_parser=ResultWrapper[Optional[ContentGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentGetResponse]], ResultWrapper[ContentGetResponse]),
        )


class AsyncContentResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncContentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncContentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncContentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncContentResourceWithStreamingResponse(self)

    async def get(
        self,
        transformer_id: int,
        *,
        account_id: str,
        version_id: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ContentGetResponse]:
        """Returns the SQL query content for a transformer.

        Without query params, returns
        the latest version. With `version_id`, returns the specified version.

        Args:
          account_id: Identifier.

          transformer_id: The transformer ID.

          version_id: Specific version ID to retrieve. When omitted, the latest version is returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/logpush/transformers/{transformer_id}/content",
                account_id=account_id,
                transformer_id=transformer_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"version_id": version_id}, content_get_params.ContentGetParams),
                post_parser=ResultWrapper[Optional[ContentGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[ContentGetResponse]], ResultWrapper[ContentGetResponse]),
        )


class ContentResourceWithRawResponse:
    def __init__(self, content: ContentResource) -> None:
        self._content = content

        self.get = to_raw_response_wrapper(
            content.get,
        )


class AsyncContentResourceWithRawResponse:
    def __init__(self, content: AsyncContentResource) -> None:
        self._content = content

        self.get = async_to_raw_response_wrapper(
            content.get,
        )


class ContentResourceWithStreamingResponse:
    def __init__(self, content: ContentResource) -> None:
        self._content = content

        self.get = to_streamed_response_wrapper(
            content.get,
        )


class AsyncContentResourceWithStreamingResponse:
    def __init__(self, content: AsyncContentResource) -> None:
        self._content = content

        self.get = async_to_streamed_response_wrapper(
            content.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = [
    "ThreatEventListParams",
    "Search",
    "SearchUnionMember0",
    "SearchUnionMember1",
    "SearchUnionMember2",
    "SearchUnionMember3",
    "SearchUnionMember4",
    "SearchUnionMember5",
]


class ThreatEventListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    cache: Literal["from-graph"]
    """Cache strategy.

    'from-graph' serves results from the graph-node KV cache when all requested
    UUIDs are cached; falls back to normal path on partial/zero hit.
    """

    cursor: str
    """Cursor for pagination.

    When provided, filters are embedded in the cursor so you only need to pass
    cursor and pageSize. Returned in the previous response's result_info.cursor
    field. Use cursor-based pagination for deep pagination (beyond 100,000 records)
    or for optimal performance.
    """

    dataset_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="datasetId")]
    """
    Dataset UUIDs to query, or one standalone scope value: 'all'/'\\**' for the legacy
    all-datasets behavior, 'analytics' for isAnalytics=true datasets, or
    'operational' for isAnalytics=false datasets. If not provided, uses the default
    dataset.
    """

    force_refresh: Annotated[bool, PropertyInfo(alias="forceRefresh")]

    format: Literal["json", "stix2", "taxii"]

    order: Literal["asc", "desc"]

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]

    page: float
    """Page number (1-indexed) for offset-based pagination.

    Limited to offset of 100,000 records. For deep pagination, use cursor-based
    pagination instead.
    """

    page_size: Annotated[float, PropertyInfo(alias="pageSize")]
    """Number of results per page. Maximum 25,000."""

    search: Iterable[Search]


class SearchUnionMember0(TypedDict, total=False):
    field: Required[
        Literal[
            "attacker",
            "attackerCountry",
            "category",
            "createdAt",
            "date",
            "event",
            "indicator",
            "indicatorType",
            "mitreAttack",
            "mitreCapec",
            "tags",
            "targetCountry",
            "targetIndustry",
            "tlp",
            "uuid",
        ]
    ]

    op: Required[
        Literal["equals", "not", "gt", "gte", "lt", "lte", "like", "contains", "startsWith", "endsWith", "find"]
    ]

    value: Required[str]


class SearchUnionMember1(TypedDict, total=False):
    field: Required[
        Literal[
            "attacker",
            "attackerCountry",
            "category",
            "createdAt",
            "date",
            "event",
            "indicator",
            "indicatorType",
            "mitreAttack",
            "mitreCapec",
            "tags",
            "targetCountry",
            "targetIndustry",
            "tlp",
            "uuid",
        ]
    ]

    op: Required[Literal["in"]]

    value: Required[SequenceNotStr[str]]


class SearchUnionMember2(TypedDict, total=False):
    field: Required[Literal["killChain"]]

    op: Required[Literal["equals", "not", "gt", "gte", "lt", "lte"]]

    value: Required[Union[float, str]]


class SearchUnionMember3(TypedDict, total=False):
    field: Required[Literal["killChain"]]

    op: Required[Literal["in"]]

    value: Required[SequenceNotStr[Union[float, str]]]


class SearchUnionMember4(TypedDict, total=False):
    field: Required[Literal["hasChildren"]]

    op: Required[Literal["equals", "not", "gt", "gte", "lt", "lte"]]

    value: Required[Union[bool, object]]


class SearchUnionMember5(TypedDict, total=False):
    field: Required[Literal["hasChildren"]]

    op: Required[Literal["in"]]

    value: Required[Iterable[Union[bool, object]]]


Search: TypeAlias = Union[
    SearchUnionMember0,
    SearchUnionMember1,
    SearchUnionMember2,
    SearchUnionMember3,
    SearchUnionMember4,
    SearchUnionMember5,
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ...._types import SequenceNotStr
from ...._utils import PropertyInfo

__all__ = [
    "TagEditParams",
    "ActiveDuration",
    "ActiveDurationUnionMember1",
    "ActorCategory",
    "ActorCategoryUnionMember1",
    "Alias",
    "AttributionOrganization",
    "AttributionOrganizationUnionMember1",
    "ExternalReference",
    "InternalAlias",
    "Motive",
    "MotiveUnionMember1",
    "OpsecLevel",
    "OpsecLevelUnionMember1",
    "OriginCountryISO",
    "OriginCountryISOUnionMember1",
    "Priority",
    "PriorityUnionMember1",
    "SophisticationLevel",
    "SophisticationLevelUnionMember1",
]


class TagEditParams(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    active_duration: Annotated[ActiveDuration, PropertyInfo(alias="activeDuration")]

    actor_category: Annotated[ActorCategory, PropertyInfo(alias="actorCategory")]

    aliases: Iterable[Alias]
    """Structured aliases ({ value, confidence 1-10, tlp }).

    Public: returned to all accounts with per-entry TLP filtering (entries with tlp:
    purple are removed for non-CFONE accounts).
    """

    alias_group_names: Annotated[SequenceNotStr[str], PropertyInfo(alias="aliasGroupNames")]

    alias_group_names_internal: Annotated[SequenceNotStr[str], PropertyInfo(alias="aliasGroupNamesInternal")]

    attribution_organization: Annotated[AttributionOrganization, PropertyInfo(alias="attributionOrganization")]

    category_uuid: Annotated[str, PropertyInfo(alias="categoryUuid")]
    """Tag type (category) UUID.

    When changed, existing `properties` are re-validated against the new category's
    schema (400 on mismatch). Set to null to unlink (typeless; properties stop being
    validated).
    """

    confidence: int
    """Overall tag confidence (1-10). Omit to preserve existing."""

    date_of_discovery: Annotated[str, PropertyInfo(alias="dateOfDiscovery")]
    """Date of discovery (ISO YYYY-MM-DD). Omit to preserve existing."""

    description: str

    external_reference_links: Annotated[SequenceNotStr[str], PropertyInfo(alias="externalReferenceLinks")]

    external_references: Annotated[Iterable[ExternalReference], PropertyInfo(alias="externalReferences")]
    """Structured external references ({ url, description }).

    Public: returned to all accounts.
    """

    internal_aliases: Annotated[Iterable[InternalAlias], PropertyInfo(alias="internalAliases")]
    """Internal structured aliases ({ value, confidence 1-10, tlp }).

    CFONE-only: never returned to non-CFONE accounts.
    """

    internal_description: Annotated[str, PropertyInfo(alias="internalDescription")]

    last_seen: Annotated[str, PropertyInfo(alias="lastSeen")]

    motive: Motive

    opsec_level: Annotated[OpsecLevel, PropertyInfo(alias="opsecLevel")]

    origin_country_iso: Annotated[OriginCountryISO, PropertyInfo(alias="originCountryISO")]

    priority: Priority

    properties: Dict[str, object]
    """Custom field values blob.

    When omitted, the existing value is preserved. When provided, performs a shallow
    per-key merge over the stored value (unmentioned keys are retained). Setting an
    individual key to null deletes that key. Validation runs against the merged
    result, so a partial update may omit a schema-required key if the stored value
    supplies it.
    """

    sophistication_level: Annotated[SophisticationLevel, PropertyInfo(alias="sophisticationLevel")]

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]
    """Tag-level TLP marking. Omit to preserve existing. Cannot be cleared to null."""

    value: str


class ActiveDurationUnionMember1(TypedDict, total=False):
    value: Required[str]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


ActiveDuration: TypeAlias = Union[str, ActiveDurationUnionMember1]


class ActorCategoryUnionMember1(TypedDict, total=False):
    value: Required[str]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


ActorCategory: TypeAlias = Union[str, ActorCategoryUnionMember1]


class Alias(TypedDict, total=False):
    value: Required[str]

    confidence: Optional[int]

    tlp: Optional[Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]]


class AttributionOrganizationUnionMember1(TypedDict, total=False):
    value: Required[str]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


AttributionOrganization: TypeAlias = Union[str, AttributionOrganizationUnionMember1]


class ExternalReference(TypedDict, total=False):
    url: Required[str]

    description: Optional[str]


class InternalAlias(TypedDict, total=False):
    value: Required[str]

    confidence: Optional[int]

    tlp: Optional[Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]]


class MotiveUnionMember1(TypedDict, total=False):
    value: Required[str]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


Motive: TypeAlias = Union[str, MotiveUnionMember1]


class OpsecLevelUnionMember1(TypedDict, total=False):
    value: Required[str]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


OpsecLevel: TypeAlias = Union[str, OpsecLevelUnionMember1]


class OriginCountryISOUnionMember1(TypedDict, total=False):
    value: Required[str]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


OriginCountryISO: TypeAlias = Union[str, OriginCountryISOUnionMember1]


class PriorityUnionMember1(TypedDict, total=False):
    value: Required[float]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


Priority: TypeAlias = Union[float, PriorityUnionMember1]


class SophisticationLevelUnionMember1(TypedDict, total=False):
    value: Required[str]

    confidence: int

    tlp: Literal["red", "amber", "amber-strict", "green", "clear", "purple", "amber+strict"]


SophisticationLevel: TypeAlias = Union[str, SophisticationLevelUnionMember1]
